@@ -505,7 +505,13 @@ query_metainfo  (GConfSource* source, const gchar* key,
       parent = NULL;
       
       if (dir != NULL)
-        return dir_get_metainfo(dir, key, err);
+        {
+          const gchar* relative_key;
+      
+          relative_key = gconf_key_key (key);
+
+          return dir_get_metainfo (dir, relative_key, err);
+        }
     }
 
   /* No metainfo found */
@@ -644,8 +650,6 @@ remove_dir      (GConfSource* source,
                  const gchar* key,
                  GError** err)
 {
-  XMLSource* xs = (XMLSource*)source;
-
   g_set_error (err, GCONF_ERROR,
                GCONF_ERROR_FAILED,
                _("Remove dir operation is no longer supported, just remove all the values in the directory"));
@@ -799,3 +803,4 @@ xs_destroy   (XMLSource* xs)
   g_free(xs->root_dir);
   g_free(xs);
 }
+
